==> windmill_api-1.46.2.tar.gz: windmill_api-1.46.2/windmill_api/models/get_app_by_version_response_200_policy_triggerables.py <==
from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.get_app_by_version_response_200_policy_triggerables_additional_property import (
    GetAppByVersionResponse200PolicyTriggerablesAdditionalProperty,
)

T = TypeVar("T", bound="GetAppByVersionResponse200PolicyTriggerables")


@attr.s(auto_attribs=True)
class GetAppByVersionResponse200PolicyTriggerables:
    """ """

    additional_properties: Dict[str, GetAppByVersionResponse200PolicyTriggerablesAdditionalProperty] = attr.ib(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        get_app_by_version_response_200_policy_triggerables = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = GetAppByVersionResponse200PolicyTriggerablesAdditionalProperty.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        get_app_by_version_response_200_policy_triggerables.additional_properties = additional_properties
        return get_app_by_version_response_200_policy_triggerables

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> GetAppByVersionResponse200PolicyTriggerablesAdditionalProperty:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: GetAppByVersionResponse200PolicyTriggerablesAdditionalProperty) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> windmill_api-1.540.2.tar.gz: windmill_api-1.540.2/windmill_api/models/get_app_by_version_response_200_policy_triggerables.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.get_app_by_version_response_200_policy_triggerables_additional_property import (
        GetAppByVersionResponse200PolicyTriggerablesAdditionalProperty,
    )


T = TypeVar("T", bound="GetAppByVersionResponse200PolicyTriggerables")


@_attrs_define
class GetAppByVersionResponse200PolicyTriggerables:
    """ """

    additional_properties: Dict[str, "GetAppByVersionResponse200PolicyTriggerablesAdditionalProperty"] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:
        pass

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.get_app_by_version_response_200_policy_triggerables_additional_property import (
            GetAppByVersionResponse200PolicyTriggerablesAdditionalProperty,
        )

        d = src_dict.copy()
        get_app_by_version_response_200_policy_triggerables = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = GetAppByVersionResponse200PolicyTriggerablesAdditionalProperty.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        get_app_by_version_response_200_policy_triggerables.additional_properties = additional_properties
        return get_app_by_version_response_200_policy_triggerables

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> "GetAppByVersionResponse200PolicyTriggerablesAdditionalProperty":
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: "GetAppByVersionResponse200PolicyTriggerablesAdditionalProperty") -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
